@@ -1,7 +1,9 @@
+"""Importing models and BetaScheduler."""
 from ncem.models.custom_callbacks import BetaScheduler
 from ncem.models.model_cvae import ModelCVAE
 from ncem.models.model_cvae_ncem import ModelCVAEncem
 from ncem.models.model_ed import ModelED
 from ncem.models.model_ed_ncem import ModelEDncem
+from ncem.models.model_ed_single_ncem import ModelEd2Ncem
 from ncem.models.model_interactions import ModelInteractions
 from ncem.models.model_linear import ModelLinear
